THE BOOST MPL LIBRARY: Placeholder Expression Definition

Front Page / Tutorial: Metafunctions and Higher-Order Metaprogramming / Lambda Details / Placeholder Expression Definition

# Placeholder Expression Definition

Now that you know just what placeholder means, we can define placeholder expression:

Definition

A placeholder expression is either:

> > - a placeholder

> or

> > - a template specialization with at least one argument that is a placeholder expression.

In other words, a placeholder expression always involves a placeholder.